@@ -519,7 +519,7 @@ class Item:
         details = None
         if exception:
             action = "error"
-            item = str(exception)
+            item = exception
             details = ''.join(traceback.format_tb(sys.exc_info()[2]))
         if self.__callback:
             self.__callback((action, item, None, details))
@@ -811,7 +811,7 @@ class Feed:
         details = None
         if exception:
             action = "error"
-            item = str(exception)
+            item = exception
             details = ''.join(traceback.format_tb(sys.exc_info()[2]))
         if self.__callback:
             self.__callback((action, item, percent, details))
@@ -837,19 +837,17 @@ class Feed:
     def __get_item_link(self, item):
         if item.guid:
             if not item.guid.has_key("ispermalink") or item.guid["ispermalink"].lower() == "true":
-                return item.guid.string
+                return self.__unquote_special(item.guid.string)
         if item.link:
             if item.link.has_key("href"):
-                return item.link["href"] #Atom uses href to store links
+                return self.__unquote_special(item.link["href"]) #Atom uses href to store links
             elif item.link.string:
-                return item.link.string
+                return self.__unquote_special(item.link.string)
             else:
                 # Once there was a feed with url in CData section
                 for node in item.link:
                     if node.string:
-                        str = node.string.strip()
-                        if str:
-                            return str
+                        return self.__unquote_special(node.string.strip())
 
 
     def __get_item_date(self, item):
