@@ -20,7 +20,7 @@ import shutil
 import sys
 from BeautifulSoup import BeautifulStoneSoup
 
-version = "0.7.6"
+version = "0.7.7"
 feed_template_default = """
 <html>
     <head>
@@ -259,8 +259,8 @@ class FeedConfig:
 
     def get_markup(self):
         if self.message_count:
-            return "<b>" + self.name + " (" + str(self.message_count) + ")</b>"
-        return self.name
+            return "<b>" + self.name.replace("&", "&amp;") + " (" + str(self.message_count) + ")</b>"
+        return self.name.replace("&", "&amp;")
 
 
     def get_print_version_keywords_string(self):
